/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.collision;

import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.river.artifacts.common.ResultFacet;
import org.dive4elements.river.artifacts.states.DefaultState.ComputeType;

/**
 * Facet for calculated river bed collision counts
 *
 * @author Matthias Schäfer
 */
public class CollisionCalcFacet extends ResultFacet {

    private static final long serialVersionUID = 1;
    private int year;

    private CollisionCalcFacet() {
        super();
        // required for clone operation deepCopy()
    }

    public CollisionCalcFacet(final int facetIndex, final int resultIndex, final int year, final String name, final String description,
            final String yAxisLabelKey, final ComputeType type, final String hash, final String stateId) {
        super(facetIndex, resultIndex, name, description, yAxisLabelKey, type, stateId, hash);

        this.year = year;
    }

    public int getYear() {
        return this.year;
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        // FIXME: why not simply use the full constructor instead?
        final CollisionCalcFacet copy = new CollisionCalcFacet();
        // FIXME: why does DataFacet does not override set? Bad access to variables of parent!
        copy.set(this);
        copy.type = this.type;
        copy.hash = this.hash;
        copy.stateId = this.stateId;
        copy.year = this.year;
        return copy;
    }
}